Description Usage Arguments Value See Also Examples
View source: R/collectBillData.R
Collect information regarding action(s) made on the bill.
1 | collectAction(x, latestonly = TRUE, progress = FALSE)
|
x |
A (or A list of) |
latestonly |
If |
progress |
If |
If latestonly==TRUE, returns data.frame object with following
contents (single row):
IntroducedDate: Date of Introduction in Actions Overview
ActLatestDate_Overview: Date of Latest Action in Actions Overview
ActLatestText_Overview: Overview Content of Latest Action in Actions Overview
ActLatestDate_All: Date of Latest Action in All Actions
ActLatestText_All: Detailed Content of Latest Action in All Actions
VoteTimes_House: Number of Voting Opportunities in House
VoteLatestDate_House: Date of Latest Vote Action in House
VoteLatestType_House: Type of Latest Vote in House
VoteLatestText_House: Content of Latest Vote in House
VoteTimes_Senate: Number of Voting Opportunities in Senate
VoteLatestDate_Senate: Date of Latest Action in Senate
VoteLatestType_Senate: Type of Latest Vote in Senate
VoteLatestText_Senate: Content of Latest Vote in Senate
RCTimes_House: Number of Roll Call Voting Opportunities in House
RCLatestDate_House: Date of Latest Roll Call in House
RCLatestText_House: Content of Latest Roll Call Vote in House
RCLatestNumber_House: ID Number of Latest Roll Call Vote in House
RCLatestYea_House: Number of Yea in Latest Roll Call Vote in House
RCLatestNay_House: Number of Nay in Latest Roll Call Vote in House
RCTimes_Senate: Number of Roll Call Voting Opportunities in Senate
RCLatestDate_Senate: Date of Latest Roll Call in Senate
RCLatestText_Senate: Content of Latest Roll Call Vote in Senate
RCLatestNumber_Senate: ID Number of Latest Roll Call Vote in Senate
RCLatestYea_Senate: Number of Yea in Latest Roll Call Vote in Senate
RCLatestNay_Senate: Number of Nay in Latest Roll Call Vote in Senate
If latestonly==FALSE, A data.frame object containing following variables:
Chamber: Chamber where the Action is Placed.
Date: Date of Action
Time: Time (in Day) of Action
Detail: Detailed Content of Action
Overview: Summarized Overview Content of Action (If Available)
Amendment: 1 if Actions is related to amendment of the bill
VoteType: Type of Vote (if any decision is made)
rollnumber: Roll Call Number if Action is Roll Call Vote
rollYea: Roll Call Yea Votes if Action is Roll Call Vote
rollNay: Roll Call Nay Votes if Action is Roll Call Vote
1 2 3 4 | tgturl <- "https://www.congress.gov/bill/115th-congress/house-bill/2"
bill2 <- scrapeBill(tgturl)
collectAction(bill2)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.